@@ -205,6 +205,8 @@ parse_workaround_flags(char *str)
         flags |= IPMI_TOOL_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION;
       else if (!strcasecmp(tok, IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION_STR))
         flags |= IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION;
+      else if (!strcasecmp (tok, IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE_STR))
+        flags |= IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE;
       else if (!strcasecmp(tok, IPMI_TOOL_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE_STR))
         flags |= IPMI_TOOL_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE;
       else if (!strcasecmp(tok, IPMI_TOOL_WORKAROUND_FLAGS_IGNORE_SOL_PORT_STR))
