@@ -1,9 +1,5 @@
 /* 
-   $Id: ipmi-sensors.h,v 1.9 2007/09/05 20:13:27 chu11 Exp $ 
-   
-   ipmi-sensors.h - IPMI Sensors utility.
-   
-   Copyright (C) 2006 FreeIPMI Core Team
+   Copyright (C) 2003-2008 FreeIPMI Core Team
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,20 +20,25 @@
 #define _IPMI_SENSORS_H
 
 #include <freeipmi/freeipmi.h>
-#include <freeipmi/udm/udm.h>
 
-#include "cmdline-parse-common.h"
-#include "ipmi-sdr-cache.h"
+#include "tool-cmdline-common.h"
+#include "tool-sdr-cache-common.h"
 #include "pstdout.h"
 
+#define IPMI_SENSORS_MAX_RECORD_IDS           256
+#define IPMI_SENSORS_MAX_GROUPS               256
+#define IPMI_SENSORS_MAX_GROUPS_STRING_LENGTH 256
+
 enum ipmi_sensors_argp_option_keys
   { 
     VERBOSE_KEY = 'v', 
     QUIET_READINGS_KEY = 'q',
     SDR_INFO_KEY = 'i', 
     LIST_GROUPS_KEY = 'L', 
-    GROUP_KEY = 'g', 
-    SENSORS_LIST_KEY = 's', 
+    GROUP_KEY = 160,            /* legacy */
+    GROUPS_KEY = 'g', 
+    SENSORS_KEY = 's', 
+    BRIDGE_SENSORS_KEY = 'b',
   };
 
 struct ipmi_sensors_arguments
@@ -45,16 +46,18 @@ struct ipmi_sensors_arguments
   struct common_cmd_args common;
   struct sdr_cmd_args sdr;
   struct hostrange_cmd_args hostrange;
-  int verbose_wanted;
+  int verbose;
   int verbose_count;
-  int quiet_readings_wanted;
-  int sdr_info_wanted;
-  int list_groups_wanted;
-  int group_wanted;
-  char *group;
-  int sensors_list_wanted;
-  unsigned int *sensors_list;
-  unsigned int sensors_list_length;
+  int quiet_readings;
+  int sdr_info;
+  int list_groups;
+  int groups_wanted;
+  char groups[IPMI_SENSORS_MAX_GROUPS][IPMI_SENSORS_MAX_GROUPS_STRING_LENGTH+1];
+  unsigned int groups_length;
+  int sensors_wanted;
+  unsigned int sensors[IPMI_SENSORS_MAX_RECORD_IDS];
+  unsigned int sensors_length;
+  int bridge_sensors;
 };
 
 typedef struct ipmi_sensors_prog_data
@@ -66,12 +69,10 @@ typedef struct ipmi_sensors_prog_data
 typedef struct ipmi_sensors_state_data
 {
   ipmi_sensors_prog_data_t *prog_data;
-  ipmi_device_t dev;
+  ipmi_ctx_t ipmi_ctx;
   pstdout_state_t pstate;
   char *hostname;
-  sdr_cache_ctx_t sdr_cache_ctx;
-  sdr_record_t *sdr_record_list;
-  unsigned int sdr_record_count;
+  ipmi_sdr_cache_ctx_t ipmi_sdr_cache_ctx;
 } ipmi_sensors_state_data_t;
 
 #endif
