@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: ipmiconsole_packet.c,v 1.26.4.3 2008/12/09 18:42:13 chu11 Exp $
+ *  $Id: ipmiconsole_packet.c,v 1.26.4.4 2009/04/08 21:12:38 chu11 Exp $
  *****************************************************************************
  *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
@@ -940,7 +940,8 @@ ipmiconsole_ipmi_packet_assemble(ipmiconsole_ctx_t c,
        *
        * Intel IPMI 2.0 implementations don't support the highest level privilege.
        */
-      if (c->config.workaround_flags & IPMICONSOLE_WORKAROUND_INTEL_2_0_SESSION)
+      if (c->config.workaround_flags & IPMICONSOLE_WORKAROUND_INTEL_2_0_SESSION
+          || c->config.workaround_flags & IPMICONSOLE_WORKAROUND_OPEN_SESSION_PRIVILEGE)
         privilege_level = c->config.privilege_level;
       else
         privilege_level = IPMI_PRIVILEGE_LEVEL_HIGHEST_LEVEL;
@@ -1572,6 +1573,11 @@ ipmiconsole_calculate_errnum(ipmiconsole_ctx_t c,
 	  ipmiconsole_ctx_set_errnum(c, IPMICONSOLE_ERR_CIPHER_SUITE_ID_UNAVAILABLE);
 	  return 0;
 	}
+      else if (rmcpplus_status_code == RMCPPLUS_STATUS_INVALID_INTEGRITY_CHECK_VALUE)
+        {
+          ipmiconsole_ctx_set_errnum (c, IPMICONSOLE_ERR_PASSWORD_INVALID);
+          return (0);
+        }
     }
   else
     {
@@ -1607,8 +1613,12 @@ ipmiconsole_calculate_errnum(ipmiconsole_ctx_t c,
 	  ipmiconsole_ctx_set_errnum(c, IPMICONSOLE_ERR_SOL_REQUIRES_NO_ENCRYPTION);
 	  return 0;
         }
+      /* Inventec 5441 returns IPMI_COMP_CODE_PARAMETER_OUT_OF_RANGE, so we'll assume
+       * that return code always means we need encryption.
+       */
       else if (p == IPMICONSOLE_PACKET_TYPE_ACTIVATE_PAYLOAD_RS
-               && comp_code == IPMI_COMP_CODE_CANNOT_ACTIVATE_PAYLOAD_WITHOUT_ENCRYPTION)
+               && (comp_code == IPMI_COMP_CODE_CANNOT_ACTIVATE_PAYLOAD_WITHOUT_ENCRYPTION
+                   || comp_code == IPMI_COMP_CODE_PARAMETER_OUT_OF_RANGE))
 	{
 	  ipmiconsole_ctx_set_errnum(c, IPMICONSOLE_ERR_SOL_REQUIRES_ENCRYPTION);
 	  return 0;
