@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: ipmi_monitoring_ipmi_communication.c,v 1.22 2008/08/12 18:14:40 chu11 Exp $
+ *  $Id: ipmi_monitoring_ipmi_communication.c,v 1.22.4.1 2009/04/08 21:12:39 chu11 Exp $
  *****************************************************************************
  *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
@@ -382,7 +382,8 @@ _ipmi_2_0_init(ipmi_monitoring_ctx_t c,
   unsigned workaround_flags_mask = (IPMI_MONITORING_WORKAROUND_FLAGS_AUTHENTICATION_CAPABILITIES
                                     | IPMI_MONITORING_WORKAROUND_FLAGS_INTEL_2_0_SESSION
                                     | IPMI_MONITORING_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION
-                                    | IPMI_MONITORING_WORKAROUND_FLAGS_SUN_2_0_SESSION);
+                                    | IPMI_MONITORING_WORKAROUND_FLAGS_SUN_2_0_SESSION
+                                    | IPMI_MONITORING_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE);
   assert(c);
   assert(c->magic == IPMI_MONITORING_MAGIC);
   assert(c->ipmi_ctx);
@@ -457,6 +458,8 @@ _ipmi_2_0_init(ipmi_monitoring_ctx_t c,
         workaround_flags |= IPMI_WORKAROUND_FLAGS_SUPERMICRO_2_0_SESSION;
       if (config->workaround_flags & IPMI_MONITORING_WORKAROUND_FLAGS_SUN_2_0_SESSION)
         workaround_flags |= IPMI_WORKAROUND_FLAGS_SUN_2_0_SESSION;
+      if (config->workaround_flags & IPMI_MONITORING_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE)
+        workaround_flags |= IPMI_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE;
     }
   
   if ((_ipmi_monitoring_flags & IPMI_MONITORING_FLAGS_DEBUG)
