@@ -1,6 +1,24 @@
+/*
+  Copyright (C) 2007-2008 FreeIPMI Core Team
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2, or (at your option)
+  any later version.
+  
+  This program is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
+*/
+
 #if HAVE_CONFIG_H
 #include "config.h"
-#endif
+#endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -13,7 +31,10 @@
 #include "pef-config-map.h"
 #include "pef-config-utils.h"
 #include "pef-config-validate.h"
-#include "pef-config-wrapper.h"
+
+#include "freeipmi-portability.h"
+#include "pstdout.h"
+#include "tool-fiid-wrappers.h"
 
 /* convenience struct */
 struct alert_policy_table {
@@ -42,52 +63,51 @@ _get_alert_policy_table (struct pef_config_state_data *state_data,
   
   alert_policy_entry_number = atoi (section_name + strlen ("Alert_Policy_"));
 
-  if (!(obj_cmd_rs = Fiid_obj_create(tmpl_cmd_get_pef_configuration_parameters_alert_policy_table_rs)))
-    goto cleanup;
+  _FIID_OBJ_CREATE(obj_cmd_rs, tmpl_cmd_get_pef_configuration_parameters_alert_policy_table_rs);
 
-  if (ipmi_cmd_get_pef_configuration_parameters_alert_policy_table (state_data->dev, 
+  if (ipmi_cmd_get_pef_configuration_parameters_alert_policy_table (state_data->ipmi_ctx, 
 								    IPMI_GET_PEF_PARAMETER,
 								    alert_policy_entry_number, 
 								    BLOCK_SELECTOR, 
 								    obj_cmd_rs) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr,
-                "ipmi_cmd_get_pef_configuration_parameters_alert_policy_table: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-      rv = CONFIG_ERR_NON_FATAL_ERROR;
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr,
+                        "ipmi_cmd_get_pef_configuration_parameters_alert_policy_table: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+      if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+        rv = CONFIG_ERR_NON_FATAL_ERROR;
       goto cleanup;
     }
 
 #if 0
-  if (Fiid_obj_get (obj_cmd_rs, "alert_policy_entry_number", &val) < 0)
-    goto cleanup;
+  _FIID_OBJ_GET (obj_cmd_rs, "alert_policy_entry_number", &val);
 #endif
-  if (Fiid_obj_get (obj_cmd_rs, "policy_number.policy_type", &val) < 0)
-    goto cleanup;
+  _FIID_OBJ_GET (obj_cmd_rs, "policy_number.policy_type", &val);
   apt->policy_type = val;
-  if (Fiid_obj_get (obj_cmd_rs, "policy_number.enabled", &val) < 0)
-    goto cleanup;
+
+  _FIID_OBJ_GET (obj_cmd_rs, "policy_number.enabled", &val);
   apt->policy_enabled = val;
-  if (Fiid_obj_get (obj_cmd_rs, "policy_number.policy_number", &val) < 0)
-    goto cleanup;
+
+  _FIID_OBJ_GET (obj_cmd_rs, "policy_number.policy_number", &val);
   apt->policy_number = val;
-  if (Fiid_obj_get (obj_cmd_rs, "channel_destination.destination_selector", &val) < 0)
-    goto cleanup;
+
+  _FIID_OBJ_GET (obj_cmd_rs, "channel_destination.destination_selector", &val);
   apt->destination_selector = val;
-  if (Fiid_obj_get (obj_cmd_rs, "channel_destination.channel_number", &val) < 0)
-    goto cleanup;
+
+  _FIID_OBJ_GET (obj_cmd_rs, "channel_destination.channel_number", &val);
   apt->channel_number = val;
-  if (Fiid_obj_get (obj_cmd_rs, "alert_string_key.alert_string_set_selector", &val) < 0)
-    goto cleanup;
+
+  _FIID_OBJ_GET (obj_cmd_rs, "alert_string_key.alert_string_set_selector", &val);
   apt->alert_string_set_selector = val;
-  if (Fiid_obj_get (obj_cmd_rs, "alert_string_key.event_specific_alert_string", &val) < 0)
-    goto cleanup;
+
+  _FIID_OBJ_GET (obj_cmd_rs, "alert_string_key.event_specific_alert_string", &val);
   apt->event_specific_alert_string = val;
   
   rv = CONFIG_ERR_SUCCESS;
  cleanup:
-  Fiid_obj_destroy(obj_cmd_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_rs);
   return (rv);
 }
 
@@ -106,10 +126,9 @@ _set_alert_policy_table (struct pef_config_state_data *state_data,
 
   alert_policy_entry_number = atoi (section_name + strlen ("Alert_Policy_"));
 
-  if (!(obj_cmd_rs = Fiid_obj_create(tmpl_cmd_set_pef_configuration_parameters_rs)))
-    goto cleanup;
+  _FIID_OBJ_CREATE(obj_cmd_rs, tmpl_cmd_set_pef_configuration_parameters_rs);
 
-  if (ipmi_cmd_set_pef_configuration_parameters_alert_policy_table (state_data->dev, 
+  if (ipmi_cmd_set_pef_configuration_parameters_alert_policy_table (state_data->ipmi_ctx, 
 								    alert_policy_entry_number, 
 								    apt->policy_type, 
 								    apt->policy_enabled, 
@@ -120,17 +139,19 @@ _set_alert_policy_table (struct pef_config_state_data *state_data,
 								    apt->event_specific_alert_string, 
 								    obj_cmd_rs) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr,
-                "ipmi_cmd_set_pef_configuration_parameters_alert_policy_table: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-      rv = CONFIG_ERR_NON_FATAL_ERROR;
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr,
+                        "ipmi_cmd_set_pef_configuration_parameters_alert_policy_table: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+      if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+        rv = CONFIG_ERR_NON_FATAL_ERROR;
       goto cleanup;
     }
       
   rv = CONFIG_ERR_SUCCESS;
  cleanup:
-  Fiid_obj_destroy(obj_cmd_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_rs);
   return (rv);
 }
 
@@ -148,7 +169,9 @@ policy_type_checkout (const char *section_name,
                                       &apt)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output(kv, policy_type_string (apt.policy_type)) < 0)
+  if (config_section_update_keyvalue_output(state_data->pstate, 
+                                            kv, 
+                                            policy_type_string (apt.policy_type)) < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -189,7 +212,9 @@ policy_enabled_checkout (const char *section_name,
                                       &apt)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output(kv, apt.policy_enabled ? "Yes" : "No") < 0)
+  if (config_section_update_keyvalue_output(state_data->pstate, 
+                                            kv, 
+                                            apt.policy_enabled ? "Yes" : "No") < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -230,7 +255,9 @@ policy_number_checkout (const char *section_name,
                                       &apt)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output_int(kv, apt.policy_number) < 0)
+  if (config_section_update_keyvalue_output_int(state_data->pstate, 
+                                                kv,
+                                                apt.policy_number) < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -271,7 +298,9 @@ destination_selector_checkout (const char *section_name,
                                       &apt)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output_int(kv, apt.destination_selector) < 0)
+  if (config_section_update_keyvalue_output_int(state_data->pstate, 
+                                                kv,
+                                                apt.destination_selector) < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -312,7 +341,9 @@ channel_number_checkout (const char *section_name,
                                       &apt)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output_int(kv, apt.channel_number) < 0)
+  if (config_section_update_keyvalue_output_int(state_data->pstate, 
+                                                kv,
+                                                apt.channel_number) < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -353,7 +384,9 @@ alert_string_set_selector_checkout (const char *section_name,
                                       &apt)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output_int(kv, apt.alert_string_set_selector) < 0)
+  if (config_section_update_keyvalue_output_int(state_data->pstate, 
+                                                kv,
+                                                apt.alert_string_set_selector) < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -394,7 +427,9 @@ event_specific_alert_string_checkout (const char *section_name,
                                       &apt)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output(kv, apt.event_specific_alert_string ? "Yes" : "No") < 0)
+  if (config_section_update_keyvalue_output(state_data->pstate, 
+                                            kv,
+                                            apt.event_specific_alert_string ? "Yes" : "No") < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -428,23 +463,30 @@ pef_config_alert_policy_table_section_get (pef_config_state_data_t *state_data,
   uint8_t lan_channel_number;
   char *strp = NULL;
   config_err_t ret;
-  char buf[64];
+  char buf[CONFIG_MAX_SECTION_NAME_LEN];
 
   if (num <= 0)
     {
-      fprintf(stderr, "Invalid Num = %d\n", num);
+      pstdout_fprintf(state_data->pstate,
+                      stderr, 
+                      "Invalid Num = %d\n",
+                      num);
       return NULL;
     }
 
-  snprintf(buf, 64, "Alert_Policy_%d", num);
+  snprintf(buf, CONFIG_MAX_SECTION_NAME_LEN, "Alert_Policy_%d", num);
 
-  if (!(section = config_section_create (buf, 
+  if (!(section = config_section_create (state_data->pstate, 
+                                         buf, 
                                          NULL, 
                                          NULL, 
-                                         0)))
+                                         0,
+                                         NULL,
+                                         NULL)))
     goto cleanup;
 
-  if (config_section_add_key (section,
+  if (config_section_add_key (state_data->pstate, 
+                              section,
                               "Policy_Type",
                               "Possible values: Always_Send_To_This_Destination/Proceed_To_Next_Entry/Do_Not_Proceed_Any_More_Entries/Proceed_To_Next_Entry_Different_Channel/Proceed_To_Next_Entry_Different_Destination_Type",
                               0,
@@ -453,7 +495,8 @@ pef_config_alert_policy_table_section_get (pef_config_state_data_t *state_data,
                               policy_type_validate) < 0) 
     goto cleanup;
 
-  if (config_section_add_key (section,
+  if (config_section_add_key (state_data->pstate, 
+                              section,
                               "Policy_Enabled",
                               "Possible values: Yes/No",
                               0,
@@ -462,7 +505,8 @@ pef_config_alert_policy_table_section_get (pef_config_state_data_t *state_data,
                               config_yes_no_validate) < 0) 
     goto cleanup;
 
-  if (config_section_add_key (section,
+  if (config_section_add_key (state_data->pstate, 
+                              section,
                               "Policy_Number",
                               "Give a valid number",
                               0,
@@ -471,7 +515,8 @@ pef_config_alert_policy_table_section_get (pef_config_state_data_t *state_data,
                               config_number_range_four_bits) < 0) 
     goto cleanup;
 
-  if (config_section_add_key (section,
+  if (config_section_add_key (state_data->pstate, 
+                              section,
                               "Destination_Selector",
                               "Give a valid number",
                               0,
@@ -482,17 +527,31 @@ pef_config_alert_policy_table_section_get (pef_config_state_data_t *state_data,
 
   ret = get_lan_channel_number (state_data, &lan_channel_number);
   if (ret == CONFIG_ERR_SUCCESS)
-    asprintf(&strp, "Give a valid number (LAN = %u)", lan_channel_number);
-  if (!strp)
     {
-      if (!(strp = "Give a valid number\n"))
+      if (asprintf(&strp, 
+                   "Give a valid number (LAN = %u)", 
+                   lan_channel_number) < 0)
         {
-          perror("strdup");
+          if (!strp)
+            {
+              pstdout_perror(state_data->pstate,
+                             "asprintf");
+              goto cleanup;
+            }
+        }
+    }
+  else
+    {
+      if (!(strp = strdup("Give a valid number")))
+        {
+          pstdout_perror(state_data->pstate,
+                         "strdup");
           goto cleanup;
         }
     }
 
-  if (config_section_add_key (section,
+  if (config_section_add_key (state_data->pstate, 
+                              section,
                               "Channel_Number",
                               strp,
                               0,
@@ -501,7 +560,8 @@ pef_config_alert_policy_table_section_get (pef_config_state_data_t *state_data,
                               config_number_range_four_bits) < 0) 
     goto cleanup;
 
-  if (config_section_add_key (section,
+  if (config_section_add_key (state_data->pstate, 
+                              section,
                               "Alert_String_Set_Selector",
                               "Give a valid number",
                               0,
@@ -510,7 +570,8 @@ pef_config_alert_policy_table_section_get (pef_config_state_data_t *state_data,
                               config_number_range_seven_bits) < 0) 
     goto cleanup;
 
-  if (config_section_add_key (section,
+  if (config_section_add_key (state_data->pstate, 
+                              section,
                               "Event_Specific_Alert_String",
                               "Possible values: Yes/No",
                               0,
@@ -527,7 +588,7 @@ pef_config_alert_policy_table_section_get (pef_config_state_data_t *state_data,
   if (strp)
     free(strp);
   if (section)
-    config_section_destroy(section);
+    config_section_destroy(state_data->pstate, section);
   return NULL;
 }
 
